==> haskell-hspec-discover-2.7.1-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-discover
version:              2.7.1
visibility:           public
id:                   hspec-discover-2.7.1-CQIJFNGucYcLQosw03BqfY
key:                  hspec-discover-2.7.1-CQIJFNGucYcLQosw03BqfY
license:              MIT
copyright:            (c) 2012-2019 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests

    <http://hspec.github.io/hspec-discover.html>

category:             Testing
abi:                  77511c02023678987de8ff9966204c31
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort

hidden-modules:       Paths_hspec_discover
import-dirs:          /usr/lib/ghc-8.8.1/site-local/hspec-discover-2.7.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/hspec-discover-2.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/hspec-discover-2.7.1
hs-libraries:         HShspec-discover-2.7.1-CQIJFNGucYcLQosw03BqfY
depends:              base-4.13.0.0 directory-1.3.3.2 filepath-1.4.2.1
haddock-interfaces:
    /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock

haddock-html:         /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-discover-2.7.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-discover
version:              2.7.1
visibility:           public
id:                   hspec-discover-2.7.1-C328yAZK1utBPCFoasqx5G
key:                  hspec-discover-2.7.1-C328yAZK1utBPCFoasqx5G
license:              MIT
copyright:            (c) 2012-2019 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests

    <http://hspec.github.io/hspec-discover.html>

category:             Testing
abi:                  7ed9f6a589ad216647bd65ec88d91221
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort

hidden-modules:       Paths_hspec_discover
import-dirs:          /usr/lib/ghc-8.8.1/site-local/hspec-discover-2.7.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/hspec-discover-2.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/hspec-discover-2.7.1
hs-libraries:         HShspec-discover-2.7.1-C328yAZK1utBPCFoasqx5G
depends:              base-4.13.0.0 directory-1.3.3.2 filepath-1.4.2.1
haddock-interfaces:
    /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock

haddock-html:         /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
